@@ -1,6 +1,7 @@
 from audiolm_pytorch.audiolm_pytorch import AudioLM
 from audiolm_pytorch.soundstream import SoundStream
 
+from audiolm_pytorch.audiolm_pytorch import SemanticBase, CoarseBase, FineBase
 from audiolm_pytorch.audiolm_pytorch import SemanticTransformer, CoarseTransformer, FineTransformer
 from audiolm_pytorch.audiolm_pytorch import FineTransformerWrapper, CoarseTransformerWrapper, SemanticTransformerWrapper
 
@@ -8,3 +9,5 @@ from audiolm_pytorch.vq_wav2vec import FairseqVQWav2Vec
 from audiolm_pytorch.hubert_kmeans import HubertWithKmeans
 
 from audiolm_pytorch.trainer import SoundStreamTrainer, SemanticTransformerTrainer, FineTransformerTrainer, CoarseTransformerTrainer
+
+from audiolm_pytorch.audiolm_pytorch import get_embeds
